# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: spec.proto
# Protobuf Python Version: 5.27.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 27, 0, "", "spec.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\nspec.proto\x12\x0b\x63om.kcl.api"1\n\x0b\x45xternalPkg\x12\x10\n\x08pkg_name\x18\x01 \x01(\t\x12\x10\n\x08pkg_path\x18\x02 \x01(\t"\'\n\x08\x41rgument\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t"L\n\x05\x45rror\x12\r\n\x05level\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12&\n\x08messages\x18\x03 \x03(\x0b\x32\x14.com.kcl.api.Message":\n\x07Message\x12\x0b\n\x03msg\x18\x01 \x01(\t\x12"\n\x03pos\x18\x02 \x01(\x0b\x32\x15.com.kcl.api.Position"\x1a\n\tPing_Args\x12\r\n\x05value\x18\x01 \x01(\t"\x1c\n\x0bPing_Result\x12\r\n\x05value\x18\x01 \x01(\t"\x11\n\x0fGetVersion_Args"]\n\x11GetVersion_Result\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x10\n\x08\x63hecksum\x18\x02 \x01(\t\x12\x0f\n\x07git_sha\x18\x03 \x01(\t\x12\x14\n\x0cversion_info\x18\x04 \x01(\t"\x11\n\x0fListMethod_Args"-\n\x11ListMethod_Result\x12\x18\n\x10method_name_list\x18\x01 \x03(\t"_\n\x0eParseFile_Args\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\t\x12/\n\rexternal_pkgs\x18\x03 \x03(\x0b\x32\x18.com.kcl.api.ExternalPkg"V\n\x10ParseFile_Result\x12\x10\n\x08\x61st_json\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65ps\x18\x02 \x03(\t\x12"\n\x06\x65rrors\x18\x03 \x03(\x0b\x32\x12.com.kcl.api.Error"d\n\x11ParseProgram_Args\x12\r\n\x05paths\x18\x01 \x03(\t\x12\x0f\n\x07sources\x18\x02 \x03(\t\x12/\n\rexternal_pkgs\x18\x03 \x03(\x0b\x32\x18.com.kcl.api.ExternalPkg"Z\n\x13ParseProgram_Result\x12\x10\n\x08\x61st_json\x18\x01 \x01(\t\x12\r\n\x05paths\x18\x02 \x03(\t\x12"\n\x06\x65rrors\x18\x03 \x03(\x0b\x32\x12.com.kcl.api.Error"\x89\x01\n\x10LoadPackage_Args\x12\x32\n\nparse_args\x18\x01 \x01(\x0b\x32\x1e.com.kcl.api.ParseProgram_Args\x12\x13\n\x0bresolve_ast\x18\x02 \x01(\x08\x12\x14\n\x0cload_builtin\x18\x03 \x01(\x08\x12\x16\n\x0ewith_ast_index\x18\x04 \x01(\x08"\xf7\x07\n\x12LoadPackage_Result\x12\x0f\n\x07program\x18\x01 \x01(\t\x12\r\n\x05paths\x18\x02 \x03(\t\x12(\n\x0cparse_errors\x18\x03 \x03(\x0b\x32\x12.com.kcl.api.Error\x12\'\n\x0btype_errors\x18\x04 \x03(\x0b\x32\x12.com.kcl.api.Error\x12;\n\x06scopes\x18\x05 \x03(\x0b\x32+.com.kcl.api.LoadPackage_Result.ScopesEntry\x12=\n\x07symbols\x18\x06 \x03(\x0b\x32,.com.kcl.api.LoadPackage_Result.SymbolsEntry\x12K\n\x0fnode_symbol_map\x18\x07 \x03(\x0b\x32\x32.com.kcl.api.LoadPackage_Result.NodeSymbolMapEntry\x12K\n\x0fsymbol_node_map\x18\x08 \x03(\x0b\x32\x32.com.kcl.api.LoadPackage_Result.SymbolNodeMapEntry\x12\\\n\x18\x66ully_qualified_name_map\x18\t \x03(\x0b\x32:.com.kcl.api.LoadPackage_Result.FullyQualifiedNameMapEntry\x12G\n\rpkg_scope_map\x18\n \x03(\x0b\x32\x30.com.kcl.api.LoadPackage_Result.PkgScopeMapEntry\x1a\x41\n\x0bScopesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.com.kcl.api.Scope:\x02\x38\x01\x1a\x43\n\x0cSymbolsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12"\n\x05value\x18\x02 \x01(\x0b\x32\x13.com.kcl.api.Symbol:\x02\x38\x01\x1aN\n\x12NodeSymbolMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.com.kcl.api.SymbolIndex:\x02\x38\x01\x1a\x34\n\x12SymbolNodeMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1aV\n\x1a\x46ullyQualifiedNameMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.com.kcl.api.SymbolIndex:\x02\x38\x01\x1aK\n\x10PkgScopeMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.com.kcl.api.ScopeIndex:\x02\x38\x01">\n\x12ListOptions_Result\x12(\n\x07options\x18\x02 \x03(\x0b\x32\x17.com.kcl.api.OptionHelp"_\n\nOptionHelp\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x10\n\x08required\x18\x03 \x01(\x08\x12\x15\n\rdefault_value\x18\x04 \x01(\t\x12\x0c\n\x04help\x18\x05 \x01(\t"\xc4\x01\n\x06Symbol\x12 \n\x02ty\x18\x01 \x01(\x0b\x32\x14.com.kcl.api.KclType\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\'\n\x05owner\x18\x03 \x01(\x0b\x32\x18.com.kcl.api.SymbolIndex\x12%\n\x03\x64\x65\x66\x18\x04 \x01(\x0b\x32\x18.com.kcl.api.SymbolIndex\x12\'\n\x05\x61ttrs\x18\x05 \x03(\x0b\x32\x18.com.kcl.api.SymbolIndex\x12\x11\n\tis_global\x18\x06 \x01(\x08"\xba\x01\n\x05Scope\x12\x0c\n\x04kind\x18\x01 \x01(\t\x12\'\n\x06parent\x18\x02 \x01(\x0b\x32\x17.com.kcl.api.ScopeIndex\x12\'\n\x05owner\x18\x03 \x01(\x0b\x32\x18.com.kcl.api.SymbolIndex\x12)\n\x08\x63hildren\x18\x04 \x03(\x0b\x32\x17.com.kcl.api.ScopeIndex\x12&\n\x04\x64\x65\x66s\x18\x05 \x03(\x0b\x32\x18.com.kcl.api.SymbolIndex"1\n\x0bSymbolIndex\x12\t\n\x01i\x18\x01 \x01(\x04\x12\t\n\x01g\x18\x02 \x01(\x04\x12\x0c\n\x04kind\x18\x03 \x01(\t"0\n\nScopeIndex\x12\t\n\x01i\x18\x01 \x01(\x04\x12\t\n\x01g\x18\x02 \x01(\x04\x12\x0c\n\x04kind\x18\x03 \x01(\t"\xd0\x03\n\x10\x45xecProgram_Args\x12\x10\n\x08work_dir\x18\x01 \x01(\t\x12\x17\n\x0fk_filename_list\x18\x02 \x03(\t\x12\x13\n\x0bk_code_list\x18\x03 \x03(\t\x12#\n\x04\x61rgs\x18\x04 \x03(\x0b\x32\x15.com.kcl.api.Argument\x12\x11\n\toverrides\x18\x05 \x03(\t\x12\x1b\n\x13\x64isable_yaml_result\x18\x06 \x01(\x08\x12\x1a\n\x12print_override_ast\x18\x07 \x01(\x08\x12\x1a\n\x12strict_range_check\x18\x08 \x01(\x08\x12\x14\n\x0c\x64isable_none\x18\t \x01(\x08\x12\x0f\n\x07verbose\x18\n \x01(\x05\x12\r\n\x05\x64\x65\x62ug\x18\x0b \x01(\x05\x12\x11\n\tsort_keys\x18\x0c \x01(\x08\x12/\n\rexternal_pkgs\x18\r \x03(\x0b\x32\x18.com.kcl.api.ExternalPkg\x12 \n\x18include_schema_type_path\x18\x0e \x01(\x08\x12\x14\n\x0c\x63ompile_only\x18\x0f \x01(\x08\x12\x13\n\x0bshow_hidden\x18\x10 \x01(\x08\x12\x15\n\rpath_selector\x18\x11 \x03(\t\x12\x11\n\tfast_eval\x18\x12 \x01(\x08"h\n\x12\x45xecProgram_Result\x12\x13\n\x0bjson_result\x18\x01 \x01(\t\x12\x13\n\x0byaml_result\x18\x02 \x01(\t\x12\x13\n\x0blog_message\x18\x03 \x01(\t\x12\x13\n\x0b\x65rr_message\x18\x04 \x01(\t"U\n\x11\x42uildProgram_Args\x12\x30\n\texec_args\x18\x01 \x01(\x0b\x32\x1d.com.kcl.api.ExecProgram_Args\x12\x0e\n\x06output\x18\x02 \x01(\t"#\n\x13\x42uildProgram_Result\x12\x0c\n\x04path\x18\x01 \x01(\t"S\n\x11\x45xecArtifact_Args\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x30\n\texec_args\x18\x02 \x01(\x0b\x32\x1d.com.kcl.api.ExecProgram_Args"!\n\x0f\x46ormatCode_Args\x12\x0e\n\x06source\x18\x01 \x01(\t"&\n\x11\x46ormatCode_Result\x12\x11\n\tformatted\x18\x01 \x01(\x0c"\x1f\n\x0f\x46ormatPath_Args\x12\x0c\n\x04path\x18\x01 \x01(\t"*\n\x11\x46ormatPath_Result\x12\x15\n\rchanged_paths\x18\x01 \x03(\t"\x1e\n\rLintPath_Args\x12\r\n\x05paths\x18\x01 \x03(\t""\n\x0fLintPath_Result\x12\x0f\n\x07results\x18\x01 \x03(\t"F\n\x11OverrideFile_Args\x12\x0c\n\x04\x66ile\x18\x01 \x01(\t\x12\r\n\x05specs\x18\x02 \x03(\t\x12\x14\n\x0cimport_paths\x18\x03 \x03(\t"O\n\x13OverrideFile_Result\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12(\n\x0cparse_errors\x18\x02 \x03(\x0b\x32\x12.com.kcl.api.Error".\n\x15ListVariables_Options\x12\x15\n\rmerge_program\x18\x01 \x01(\x08"8\n\x0cVariableList\x12(\n\tvariables\x18\x01 \x03(\x0b\x32\x15.com.kcl.api.Variable"g\n\x12ListVariables_Args\x12\r\n\x05\x66iles\x18\x01 \x03(\t\x12\r\n\x05specs\x18\x02 \x03(\t\x12\x33\n\x07options\x18\x03 \x01(\x0b\x32".com.kcl.api.ListVariables_Options"\xed\x01\n\x14ListVariables_Result\x12\x43\n\tvariables\x18\x01 \x03(\x0b\x32\x30.com.kcl.api.ListVariables_Result.VariablesEntry\x12\x19\n\x11unsupported_codes\x18\x02 \x03(\t\x12(\n\x0cparse_errors\x18\x03 \x03(\x0b\x32\x12.com.kcl.api.Error\x1aK\n\x0eVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.com.kcl.api.VariableList:\x02\x38\x01"\x94\x01\n\x08Variable\x12\r\n\x05value\x18\x01 \x01(\t\x12\x11\n\ttype_name\x18\x02 \x01(\t\x12\x0e\n\x06op_sym\x18\x03 \x01(\t\x12)\n\nlist_items\x18\x04 \x03(\x0b\x32\x15.com.kcl.api.Variable\x12+\n\x0c\x64ict_entries\x18\x05 \x03(\x0b\x32\x15.com.kcl.api.MapEntry"=\n\x08MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.com.kcl.api.Variable"b\n\x19GetSchemaTypeMapping_Args\x12\x30\n\texec_args\x18\x01 \x01(\x0b\x32\x1d.com.kcl.api.ExecProgram_Args\x12\x13\n\x0bschema_name\x18\x02 \x01(\t"\xcb\x01\n\x1bGetSchemaTypeMapping_Result\x12\\\n\x13schema_type_mapping\x18\x01 \x03(\x0b\x32?.com.kcl.api.GetSchemaTypeMapping_Result.SchemaTypeMappingEntry\x1aN\n\x16SchemaTypeMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.com.kcl.api.KclType:\x02\x38\x01"\x87\x01\n\x11ValidateCode_Args\x12\x10\n\x08\x64\x61tafile\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\t\x12\x0c\n\x04\x66ile\x18\x03 \x01(\t\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t\x12\x0e\n\x06schema\x18\x05 \x01(\t\x12\x16\n\x0e\x61ttribute_name\x18\x06 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x07 \x01(\t";\n\x13ValidateCode_Result\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x13\n\x0b\x65rr_message\x18\x02 \x01(\t":\n\x08Position\x12\x0c\n\x04line\x18\x01 \x01(\x03\x12\x0e\n\x06\x63olumn\x18\x02 \x01(\x03\x12\x10\n\x08\x66ilename\x18\x03 \x01(\t"i\n\x11ListDepFiles_Args\x12\x10\n\x08work_dir\x18\x01 \x01(\t\x12\x14\n\x0cuse_abs_path\x18\x02 \x01(\x08\x12\x13\n\x0binclude_all\x18\x03 \x01(\x08\x12\x17\n\x0fuse_fast_parser\x18\x04 \x01(\x08"F\n\x13ListDepFiles_Result\x12\x0f\n\x07pkgroot\x18\x01 \x01(\t\x12\x0f\n\x07pkgpath\x18\x02 \x01(\t\x12\r\n\x05\x66iles\x18\x03 \x03(\t"9\n\x16LoadSettingsFiles_Args\x12\x10\n\x08work_dir\x18\x01 \x01(\t\x12\r\n\x05\x66iles\x18\x02 \x03(\t"{\n\x18LoadSettingsFiles_Result\x12/\n\x0fkcl_cli_configs\x18\x01 \x01(\x0b\x32\x16.com.kcl.api.CliConfig\x12.\n\x0bkcl_options\x18\x02 \x03(\x0b\x32\x19.com.kcl.api.KeyValuePair"\x83\x02\n\tCliConfig\x12\r\n\x05\x66iles\x18\x01 \x03(\t\x12\x0e\n\x06output\x18\x02 \x01(\t\x12\x11\n\toverrides\x18\x03 \x03(\t\x12\x15\n\rpath_selector\x18\x04 \x03(\t\x12\x1a\n\x12strict_range_check\x18\x05 \x01(\x08\x12\x14\n\x0c\x64isable_none\x18\x06 \x01(\x08\x12\x0f\n\x07verbose\x18\x07 \x01(\x03\x12\r\n\x05\x64\x65\x62ug\x18\x08 \x01(\x08\x12\x11\n\tsort_keys\x18\t \x01(\x08\x12\x13\n\x0bshow_hidden\x18\n \x01(\x08\x12 \n\x18include_schema_type_path\x18\x0b \x01(\x08\x12\x11\n\tfast_eval\x18\x0c \x01(\x08"*\n\x0cKeyValuePair\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t"^\n\x0bRename_Args\x12\x14\n\x0cpackage_root\x18\x01 \x01(\t\x12\x13\n\x0bsymbol_path\x18\x02 \x01(\t\x12\x12\n\nfile_paths\x18\x03 \x03(\t\x12\x10\n\x08new_name\x18\x04 \x01(\t"&\n\rRename_Result\x12\x15\n\rchanged_files\x18\x01 \x03(\t"\xc7\x01\n\x0fRenameCode_Args\x12\x14\n\x0cpackage_root\x18\x01 \x01(\t\x12\x13\n\x0bsymbol_path\x18\x02 \x01(\t\x12\x43\n\x0csource_codes\x18\x03 \x03(\x0b\x32-.com.kcl.api.RenameCode_Args.SourceCodesEntry\x12\x10\n\x08new_name\x18\x04 \x01(\t\x1a\x32\n\x10SourceCodesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"\x91\x01\n\x11RenameCode_Result\x12G\n\rchanged_codes\x18\x01 \x03(\x0b\x32\x30.com.kcl.api.RenameCode_Result.ChangedCodesEntry\x1a\x33\n\x11\x43hangedCodesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"v\n\tTest_Args\x12\x30\n\texec_args\x18\x01 \x01(\x0b\x32\x1d.com.kcl.api.ExecProgram_Args\x12\x10\n\x08pkg_list\x18\x02 \x03(\t\x12\x12\n\nrun_regexp\x18\x03 \x01(\t\x12\x11\n\tfail_fast\x18\x04 \x01(\x08"6\n\x0bTest_Result\x12\'\n\x04info\x18\x02 \x03(\x0b\x32\x19.com.kcl.api.TestCaseInfo"R\n\x0cTestCaseInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x12\x10\n\x08\x64uration\x18\x03 \x01(\x04\x12\x13\n\x0blog_message\x18\x04 \x01(\t"@\n\x17UpdateDependencies_Args\x12\x15\n\rmanifest_path\x18\x01 \x01(\t\x12\x0e\n\x06vendor\x18\x02 \x01(\x08"L\n\x19UpdateDependencies_Result\x12/\n\rexternal_pkgs\x18\x03 \x03(\x0b\x32\x18.com.kcl.api.ExternalPkg"\xf3\x04\n\x07KclType\x12\x0c\n\x04type\x18\x01 \x01(\t\x12)\n\x0bunion_types\x18\x02 \x03(\x0b\x32\x14.com.kcl.api.KclType\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\x03 \x01(\t\x12\x13\n\x0bschema_name\x18\x04 \x01(\t\x12\x12\n\nschema_doc\x18\x05 \x01(\t\x12\x38\n\nproperties\x18\x06 \x03(\x0b\x32$.com.kcl.api.KclType.PropertiesEntry\x12\x10\n\x08required\x18\x07 \x03(\t\x12!\n\x03key\x18\x08 \x01(\x0b\x32\x14.com.kcl.api.KclType\x12"\n\x04item\x18\t \x01(\x0b\x32\x14.com.kcl.api.KclType\x12\x0c\n\x04line\x18\n \x01(\x05\x12*\n\ndecorators\x18\x0b \x03(\x0b\x32\x16.com.kcl.api.Decorator\x12\x10\n\x08\x66ilename\x18\x0c \x01(\t\x12\x10\n\x08pkg_path\x18\r \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x0e \x01(\t\x12\x34\n\x08\x65xamples\x18\x0f \x03(\x0b\x32".com.kcl.api.KclType.ExamplesEntry\x12)\n\x0b\x62\x61se_schema\x18\x10 \x01(\x0b\x32\x14.com.kcl.api.KclType\x1aG\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.com.kcl.api.KclType:\x02\x38\x01\x1a\x45\n\rExamplesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.com.kcl.api.Example:\x02\x38\x01"\x95\x01\n\tDecorator\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\targuments\x18\x02 \x03(\t\x12\x36\n\x08keywords\x18\x03 \x03(\x0b\x32$.com.kcl.api.Decorator.KeywordsEntry\x1a/\n\rKeywordsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01">\n\x07\x45xample\x12\x0f\n\x07summary\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t2\x96\x01\n\x0e\x42uiltinService\x12\x38\n\x04Ping\x12\x16.com.kcl.api.Ping_Args\x1a\x18.com.kcl.api.Ping_Result\x12J\n\nListMethod\x12\x1c.com.kcl.api.ListMethod_Args\x1a\x1e.com.kcl.api.ListMethod_Result2\xde\r\n\x0cKclvmService\x12\x38\n\x04Ping\x12\x16.com.kcl.api.Ping_Args\x1a\x18.com.kcl.api.Ping_Result\x12J\n\nGetVersion\x12\x1c.com.kcl.api.GetVersion_Args\x1a\x1e.com.kcl.api.GetVersion_Result\x12P\n\x0cParseProgram\x12\x1e.com.kcl.api.ParseProgram_Args\x1a .com.kcl.api.ParseProgram_Result\x12G\n\tParseFile\x12\x1b.com.kcl.api.ParseFile_Args\x1a\x1d.com.kcl.api.ParseFile_Result\x12M\n\x0bLoadPackage\x12\x1d.com.kcl.api.LoadPackage_Args\x1a\x1f.com.kcl.api.LoadPackage_Result\x12N\n\x0bListOptions\x12\x1e.com.kcl.api.ParseProgram_Args\x1a\x1f.com.kcl.api.ListOptions_Result\x12S\n\rListVariables\x12\x1f.com.kcl.api.ListVariables_Args\x1a!.com.kcl.api.ListVariables_Result\x12M\n\x0b\x45xecProgram\x12\x1d.com.kcl.api.ExecProgram_Args\x1a\x1f.com.kcl.api.ExecProgram_Result\x12P\n\x0c\x42uildProgram\x12\x1e.com.kcl.api.BuildProgram_Args\x1a .com.kcl.api.BuildProgram_Result\x12O\n\x0c\x45xecArtifact\x12\x1e.com.kcl.api.ExecArtifact_Args\x1a\x1f.com.kcl.api.ExecProgram_Result\x12P\n\x0cOverrideFile\x12\x1e.com.kcl.api.OverrideFile_Args\x1a .com.kcl.api.OverrideFile_Result\x12h\n\x14GetSchemaTypeMapping\x12&.com.kcl.api.GetSchemaTypeMapping_Args\x1a(.com.kcl.api.GetSchemaTypeMapping_Result\x12J\n\nFormatCode\x12\x1c.com.kcl.api.FormatCode_Args\x1a\x1e.com.kcl.api.FormatCode_Result\x12J\n\nFormatPath\x12\x1c.com.kcl.api.FormatPath_Args\x1a\x1e.com.kcl.api.FormatPath_Result\x12\x44\n\x08LintPath\x12\x1a.com.kcl.api.LintPath_Args\x1a\x1c.com.kcl.api.LintPath_Result\x12P\n\x0cValidateCode\x12\x1e.com.kcl.api.ValidateCode_Args\x1a .com.kcl.api.ValidateCode_Result\x12P\n\x0cListDepFiles\x12\x1e.com.kcl.api.ListDepFiles_Args\x1a .com.kcl.api.ListDepFiles_Result\x12_\n\x11LoadSettingsFiles\x12#.com.kcl.api.LoadSettingsFiles_Args\x1a%.com.kcl.api.LoadSettingsFiles_Result\x12>\n\x06Rename\x12\x18.com.kcl.api.Rename_Args\x1a\x1a.com.kcl.api.Rename_Result\x12J\n\nRenameCode\x12\x1c.com.kcl.api.RenameCode_Args\x1a\x1e.com.kcl.api.RenameCode_Result\x12\x38\n\x04Test\x12\x16.com.kcl.api.Test_Args\x1a\x18.com.kcl.api.Test_Result\x12\x62\n\x12UpdateDependencies\x12$.com.kcl.api.UpdateDependencies_Args\x1a&.com.kcl.api.UpdateDependencies_ResultB\x14Z\x05.;lib\xaa\x02\nKclLib.APIb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "spec_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\005.;lib\252\002\nKclLib.API"
    _globals["_LOADPACKAGE_RESULT_SCOPESENTRY"]._loaded_options = None
    _globals["_LOADPACKAGE_RESULT_SCOPESENTRY"]._serialized_options = b"8\001"
    _globals["_LOADPACKAGE_RESULT_SYMBOLSENTRY"]._loaded_options = None
    _globals["_LOADPACKAGE_RESULT_SYMBOLSENTRY"]._serialized_options = b"8\001"
    _globals["_LOADPACKAGE_RESULT_NODESYMBOLMAPENTRY"]._loaded_options = None
    _globals["_LOADPACKAGE_RESULT_NODESYMBOLMAPENTRY"]._serialized_options = b"8\001"
    _globals["_LOADPACKAGE_RESULT_SYMBOLNODEMAPENTRY"]._loaded_options = None
    _globals["_LOADPACKAGE_RESULT_SYMBOLNODEMAPENTRY"]._serialized_options = b"8\001"
    _globals["_LOADPACKAGE_RESULT_FULLYQUALIFIEDNAMEMAPENTRY"]._loaded_options = None
    _globals["_LOADPACKAGE_RESULT_FULLYQUALIFIEDNAMEMAPENTRY"]._serialized_options = (
        b"8\001"
    )
    _globals["_LOADPACKAGE_RESULT_PKGSCOPEMAPENTRY"]._loaded_options = None
    _globals["_LOADPACKAGE_RESULT_PKGSCOPEMAPENTRY"]._serialized_options = b"8\001"
    _globals["_LISTVARIABLES_RESULT_VARIABLESENTRY"]._loaded_options = None
    _globals["_LISTVARIABLES_RESULT_VARIABLESENTRY"]._serialized_options = b"8\001"
    _globals["_GETSCHEMATYPEMAPPING_RESULT_SCHEMATYPEMAPPINGENTRY"]._loaded_options = (
        None
    )
    _globals[
        "_GETSCHEMATYPEMAPPING_RESULT_SCHEMATYPEMAPPINGENTRY"
    ]._serialized_options = b"8\001"
    _globals["_RENAMECODE_ARGS_SOURCECODESENTRY"]._loaded_options = None
    _globals["_RENAMECODE_ARGS_SOURCECODESENTRY"]._serialized_options = b"8\001"
    _globals["_RENAMECODE_RESULT_CHANGEDCODESENTRY"]._loaded_options = None
    _globals["_RENAMECODE_RESULT_CHANGEDCODESENTRY"]._serialized_options = b"8\001"
    _globals["_KCLTYPE_PROPERTIESENTRY"]._loaded_options = None
    _globals["_KCLTYPE_PROPERTIESENTRY"]._serialized_options = b"8\001"
    _globals["_KCLTYPE_EXAMPLESENTRY"]._loaded_options = None
    _globals["_KCLTYPE_EXAMPLESENTRY"]._serialized_options = b"8\001"
    _globals["_DECORATOR_KEYWORDSENTRY"]._loaded_options = None
    _globals["_DECORATOR_KEYWORDSENTRY"]._serialized_options = b"8\001"
    _globals["_EXTERNALPKG"]._serialized_start = 27
    _globals["_EXTERNALPKG"]._serialized_end = 76
    _globals["_ARGUMENT"]._serialized_start = 78
    _globals["_ARGUMENT"]._serialized_end = 117
    _globals["_ERROR"]._serialized_start = 119
    _globals["_ERROR"]._serialized_end = 195
    _globals["_MESSAGE"]._serialized_start = 197
    _globals["_MESSAGE"]._serialized_end = 255
    _globals["_PING_ARGS"]._serialized_start = 257
    _globals["_PING_ARGS"]._serialized_end = 283
    _globals["_PING_RESULT"]._serialized_start = 285
    _globals["_PING_RESULT"]._serialized_end = 313
    _globals["_GETVERSION_ARGS"]._serialized_start = 315
    _globals["_GETVERSION_ARGS"]._serialized_end = 332
    _globals["_GETVERSION_RESULT"]._serialized_start = 334
    _globals["_GETVERSION_RESULT"]._serialized_end = 427
    _globals["_LISTMETHOD_ARGS"]._serialized_start = 429
    _globals["_LISTMETHOD_ARGS"]._serialized_end = 446
    _globals["_LISTMETHOD_RESULT"]._serialized_start = 448
    _globals["_LISTMETHOD_RESULT"]._serialized_end = 493
    _globals["_PARSEFILE_ARGS"]._serialized_start = 495
    _globals["_PARSEFILE_ARGS"]._serialized_end = 590
    _globals["_PARSEFILE_RESULT"]._serialized_start = 592
    _globals["_PARSEFILE_RESULT"]._serialized_end = 678
    _globals["_PARSEPROGRAM_ARGS"]._serialized_start = 680
    _globals["_PARSEPROGRAM_ARGS"]._serialized_end = 780
    _globals["_PARSEPROGRAM_RESULT"]._serialized_start = 782
    _globals["_PARSEPROGRAM_RESULT"]._serialized_end = 872
    _globals["_LOADPACKAGE_ARGS"]._serialized_start = 875
    _globals["_LOADPACKAGE_ARGS"]._serialized_end = 1012
    _globals["_LOADPACKAGE_RESULT"]._serialized_start = 1015
    _globals["_LOADPACKAGE_RESULT"]._serialized_end = 2030
    _globals["_LOADPACKAGE_RESULT_SCOPESENTRY"]._serialized_start = 1597
    _globals["_LOADPACKAGE_RESULT_SCOPESENTRY"]._serialized_end = 1662
    _globals["_LOADPACKAGE_RESULT_SYMBOLSENTRY"]._serialized_start = 1664
    _globals["_LOADPACKAGE_RESULT_SYMBOLSENTRY"]._serialized_end = 1731
    _globals["_LOADPACKAGE_RESULT_NODESYMBOLMAPENTRY"]._serialized_start = 1733
    _globals["_LOADPACKAGE_RESULT_NODESYMBOLMAPENTRY"]._serialized_end = 1811
    _globals["_LOADPACKAGE_RESULT_SYMBOLNODEMAPENTRY"]._serialized_start = 1813
    _globals["_LOADPACKAGE_RESULT_SYMBOLNODEMAPENTRY"]._serialized_end = 1865
    _globals["_LOADPACKAGE_RESULT_FULLYQUALIFIEDNAMEMAPENTRY"]._serialized_start = 1867
    _globals["_LOADPACKAGE_RESULT_FULLYQUALIFIEDNAMEMAPENTRY"]._serialized_end = 1953
    _globals["_LOADPACKAGE_RESULT_PKGSCOPEMAPENTRY"]._serialized_start = 1955
    _globals["_LOADPACKAGE_RESULT_PKGSCOPEMAPENTRY"]._serialized_end = 2030
    _globals["_LISTOPTIONS_RESULT"]._serialized_start = 2032
    _globals["_LISTOPTIONS_RESULT"]._serialized_end = 2094
    _globals["_OPTIONHELP"]._serialized_start = 2096
    _globals["_OPTIONHELP"]._serialized_end = 2191
    _globals["_SYMBOL"]._serialized_start = 2194
    _globals["_SYMBOL"]._serialized_end = 2390
    _globals["_SCOPE"]._serialized_start = 2393
    _globals["_SCOPE"]._serialized_end = 2579
    _globals["_SYMBOLINDEX"]._serialized_start = 2581
    _globals["_SYMBOLINDEX"]._serialized_end = 2630
    _globals["_SCOPEINDEX"]._serialized_start = 2632
    _globals["_SCOPEINDEX"]._serialized_end = 2680
    _globals["_EXECPROGRAM_ARGS"]._serialized_start = 2683
    _globals["_EXECPROGRAM_ARGS"]._serialized_end = 3147
    _globals["_EXECPROGRAM_RESULT"]._serialized_start = 3149
    _globals["_EXECPROGRAM_RESULT"]._serialized_end = 3253
    _globals["_BUILDPROGRAM_ARGS"]._serialized_start = 3255
    _globals["_BUILDPROGRAM_ARGS"]._serialized_end = 3340
    _globals["_BUILDPROGRAM_RESULT"]._serialized_start = 3342
    _globals["_BUILDPROGRAM_RESULT"]._serialized_end = 3377
    _globals["_EXECARTIFACT_ARGS"]._serialized_start = 3379
    _globals["_EXECARTIFACT_ARGS"]._serialized_end = 3462
    _globals["_FORMATCODE_ARGS"]._serialized_start = 3464
    _globals["_FORMATCODE_ARGS"]._serialized_end = 3497
    _globals["_FORMATCODE_RESULT"]._serialized_start = 3499
    _globals["_FORMATCODE_RESULT"]._serialized_end = 3537
    _globals["_FORMATPATH_ARGS"]._serialized_start = 3539
    _globals["_FORMATPATH_ARGS"]._serialized_end = 3570
    _globals["_FORMATPATH_RESULT"]._serialized_start = 3572
    _globals["_FORMATPATH_RESULT"]._serialized_end = 3614
    _globals["_LINTPATH_ARGS"]._serialized_start = 3616
    _globals["_LINTPATH_ARGS"]._serialized_end = 3646
    _globals["_LINTPATH_RESULT"]._serialized_start = 3648
    _globals["_LINTPATH_RESULT"]._serialized_end = 3682
    _globals["_OVERRIDEFILE_ARGS"]._serialized_start = 3684
    _globals["_OVERRIDEFILE_ARGS"]._serialized_end = 3754
    _globals["_OVERRIDEFILE_RESULT"]._serialized_start = 3756
    _globals["_OVERRIDEFILE_RESULT"]._serialized_end = 3835
    _globals["_LISTVARIABLES_OPTIONS"]._serialized_start = 3837
    _globals["_LISTVARIABLES_OPTIONS"]._serialized_end = 3883
    _globals["_VARIABLELIST"]._serialized_start = 3885
    _globals["_VARIABLELIST"]._serialized_end = 3941
    _globals["_LISTVARIABLES_ARGS"]._serialized_start = 3943
    _globals["_LISTVARIABLES_ARGS"]._serialized_end = 4046
    _globals["_LISTVARIABLES_RESULT"]._serialized_start = 4049
    _globals["_LISTVARIABLES_RESULT"]._serialized_end = 4286
    _globals["_LISTVARIABLES_RESULT_VARIABLESENTRY"]._serialized_start = 4211
    _globals["_LISTVARIABLES_RESULT_VARIABLESENTRY"]._serialized_end = 4286
    _globals["_VARIABLE"]._serialized_start = 4289
    _globals["_VARIABLE"]._serialized_end = 4437
    _globals["_MAPENTRY"]._serialized_start = 4439
    _globals["_MAPENTRY"]._serialized_end = 4500
    _globals["_GETSCHEMATYPEMAPPING_ARGS"]._serialized_start = 4502
    _globals["_GETSCHEMATYPEMAPPING_ARGS"]._serialized_end = 4600
    _globals["_GETSCHEMATYPEMAPPING_RESULT"]._serialized_start = 4603
    _globals["_GETSCHEMATYPEMAPPING_RESULT"]._serialized_end = 4806
    _globals[
        "_GETSCHEMATYPEMAPPING_RESULT_SCHEMATYPEMAPPINGENTRY"
    ]._serialized_start = 4728
    _globals["_GETSCHEMATYPEMAPPING_RESULT_SCHEMATYPEMAPPINGENTRY"]._serialized_end = (
        4806
    )
    _globals["_VALIDATECODE_ARGS"]._serialized_start = 4809
    _globals["_VALIDATECODE_ARGS"]._serialized_end = 4944
    _globals["_VALIDATECODE_RESULT"]._serialized_start = 4946
    _globals["_VALIDATECODE_RESULT"]._serialized_end = 5005
    _globals["_POSITION"]._serialized_start = 5007
    _globals["_POSITION"]._serialized_end = 5065
    _globals["_LISTDEPFILES_ARGS"]._serialized_start = 5067
    _globals["_LISTDEPFILES_ARGS"]._serialized_end = 5172
    _globals["_LISTDEPFILES_RESULT"]._serialized_start = 5174
    _globals["_LISTDEPFILES_RESULT"]._serialized_end = 5244
    _globals["_LOADSETTINGSFILES_ARGS"]._serialized_start = 5246
    _globals["_LOADSETTINGSFILES_ARGS"]._serialized_end = 5303
    _globals["_LOADSETTINGSFILES_RESULT"]._serialized_start = 5305
    _globals["_LOADSETTINGSFILES_RESULT"]._serialized_end = 5428
    _globals["_CLICONFIG"]._serialized_start = 5431
    _globals["_CLICONFIG"]._serialized_end = 5690
    _globals["_KEYVALUEPAIR"]._serialized_start = 5692
    _globals["_KEYVALUEPAIR"]._serialized_end = 5734
    _globals["_RENAME_ARGS"]._serialized_start = 5736
    _globals["_RENAME_ARGS"]._serialized_end = 5830
    _globals["_RENAME_RESULT"]._serialized_start = 5832
    _globals["_RENAME_RESULT"]._serialized_end = 5870
    _globals["_RENAMECODE_ARGS"]._serialized_start = 5873
    _globals["_RENAMECODE_ARGS"]._serialized_end = 6072
    _globals["_RENAMECODE_ARGS_SOURCECODESENTRY"]._serialized_start = 6022
    _globals["_RENAMECODE_ARGS_SOURCECODESENTRY"]._serialized_end = 6072
    _globals["_RENAMECODE_RESULT"]._serialized_start = 6075
    _globals["_RENAMECODE_RESULT"]._serialized_end = 6220
    _globals["_RENAMECODE_RESULT_CHANGEDCODESENTRY"]._serialized_start = 6169
    _globals["_RENAMECODE_RESULT_CHANGEDCODESENTRY"]._serialized_end = 6220
    _globals["_TEST_ARGS"]._serialized_start = 6222
    _globals["_TEST_ARGS"]._serialized_end = 6340
    _globals["_TEST_RESULT"]._serialized_start = 6342
    _globals["_TEST_RESULT"]._serialized_end = 6396
    _globals["_TESTCASEINFO"]._serialized_start = 6398
    _globals["_TESTCASEINFO"]._serialized_end = 6480
    _globals["_UPDATEDEPENDENCIES_ARGS"]._serialized_start = 6482
    _globals["_UPDATEDEPENDENCIES_ARGS"]._serialized_end = 6546
    _globals["_UPDATEDEPENDENCIES_RESULT"]._serialized_start = 6548
    _globals["_UPDATEDEPENDENCIES_RESULT"]._serialized_end = 6624
    _globals["_KCLTYPE"]._serialized_start = 6627
    _globals["_KCLTYPE"]._serialized_end = 7254
    _globals["_KCLTYPE_PROPERTIESENTRY"]._serialized_start = 7112
    _globals["_KCLTYPE_PROPERTIESENTRY"]._serialized_end = 7183
    _globals["_KCLTYPE_EXAMPLESENTRY"]._serialized_start = 7185
    _globals["_KCLTYPE_EXAMPLESENTRY"]._serialized_end = 7254
    _globals["_DECORATOR"]._serialized_start = 7257
    _globals["_DECORATOR"]._serialized_end = 7406
    _globals["_DECORATOR_KEYWORDSENTRY"]._serialized_start = 7359
    _globals["_DECORATOR_KEYWORDSENTRY"]._serialized_end = 7406
    _globals["_EXAMPLE"]._serialized_start = 7408
    _globals["_EXAMPLE"]._serialized_end = 7470
    _globals["_BUILTINSERVICE"]._serialized_start = 7473
    _globals["_BUILTINSERVICE"]._serialized_end = 7623
    _globals["_KCLVMSERVICE"]._serialized_start = 7626
    _globals["_KCLVMSERVICE"]._serialized_end = 9384
# @@protoc_insertion_point(module_scope)
